# Generated by roxygen2: do not edit by hand

S3method(coef,student_t_naive_bayes)
S3method(plot,student_t_naive_bayes)
S3method(predict,student_t_naive_bayes)
S3method(print,student_t_naive_bayes)
S3method(summary,student_t_naive_bayes)
S3method(tables,default)
S3method(tables,student_t_naive_bayes)
export(student_t_naive_bayes)
export(tables)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(stats,dt)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(utils,modifyList)
